#ifndef NT2_INCLUDE_FUNCTIONS_ERFINV_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ERFINV_HPP_INCLUDED

#include <nt2/euler/include/functions/erfinv.hpp>

#endif
